/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.weblogic.support.internal;

import com.liferay.portal.kernel.util.ServerDetector;
import com.liferay.portal.servlet.filters.weblogic.WebLogicIncludeServletResponseFactory;
import com.liferay.portal.weblogic.support.internal.include.WebLogicIncludeServletResponseFactoryImpl;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;

/**
 * @author Shuyang Zhou
 */
@Component(immediate = true, service = {})
public class WebLogicSupport {

	@Activate
	protected void activate(BundleContext bundleContext) {
		if (!ServerDetector.isWebLogic()) {
			return;
		}

		_serviceRegistration = bundleContext.registerService(
			WebLogicIncludeServletResponseFactory.class,
			new WebLogicIncludeServletResponseFactoryImpl(), null);
	}

	@Deactivate
	protected void deactivate() {
		if (!ServerDetector.isWebLogic()) {
			return;
		}

		_serviceRegistration.unregister();
	}

	private ServiceRegistration<WebLogicIncludeServletResponseFactory>
		_serviceRegistration;

}